ValidatorInstance<T> class
Constructors
-
ValidatorInstance({required List<
InputValidatorPart< parts, required bool stopOnFirstError, required bool stopOnFirstErrorOrWarning})T> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopOnFirstError → bool
-
Stops validation on first error.
final
- stopOnFirstErrorOrWarning → bool
-
Stop validation on first error or warning.
final
Methods
-
bindInput(
GladeInput< T> input) → void -
findValidatorPart(
Object key) → InputValidatorPart< T> -
hasDeclaredValidator(
Object key) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryFindValidatorPart(
Object key) → InputValidatorPart< T> ? -
validate(
T value) → ValidatorResult< T> -
Performs validation on given
value.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited